.. _ydoc directive_2 directive_2b:

``directive_2b``
================

Directive 2b is another possible directive

Single-valued parameters:

  * ``val1``: Val 1 of D2b (default: a_nice_value)

  * ``val2``: Val 2 of D2b (default: a_not_so_nice_value)



----

This page was automatically generated by **ycleptic** v1.8.0 on 2025-08-04.